pub enum VectorConfig {
DenseConfig(DenseVectorCreationConfig),
SparseConfig(SparseVectorCreationConfig),
}Expand description
Configuration for the new vector - either dense or sparse
Variants
DenseConfig(DenseVectorCreationConfig)
Dense vector parameters
SparseConfig(SparseVectorCreationConfig)
Sparse vector parameters
Implementations
Sourceimpl VectorConfig
impl VectorConfig
Sourcepub fn merge(
field: &mut Option<VectorConfig>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<VectorConfig>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.