#[repr(i32)]pub enum Memory {
Unknown = 0,
Cold = 1,
Cached = 2,
Pinned = 3,
}Expand description
Memory placement of a component’s data. Data is always persisted on disk regardless of this setting; it only controls how the data is held in RAM.
Variants
Unknown = 0
Cold = 1
Data is not pre-loaded from disk to RAM; cached with usage.
Cached = 2
Data is pre-loaded into disk-cache RAM on start, but may be evicted under memory pressure.
Pinned = 3
Data is loaded in RAM and never evicted.
Implementations
Sourceimpl Memory
impl Memory
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.