#[repr(i32)]pub enum UpdateMode {
Upsert = 0,
InsertOnly = 1,
UpdateOnly = 2,
}Expand description
Defines the mode of the upsert operation
Variants
Upsert = 0
Default mode - insert new points, update existing points
InsertOnly = 1
Only insert new points, do not update existing points
UpdateOnly = 2
Only update existing points, do not insert new points
Implementations
Sourceimpl UpdateMode
impl UpdateMode
Sourceimpl UpdateMode
impl UpdateMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.