PointStructList

Struct PointStructList 

pub struct PointStructList {
    pub points: Vec<PointStruct>,
    pub shard_key_selector: Option<ShardKeySelector>,
    pub update_filter: Option<Filter>,
    pub update_mode: Option<i32>,
}

Fields

points: Vec<PointStruct>shard_key_selector: Option<ShardKeySelector>

Option for custom sharding to specify used shard keys

update_filter: Option<Filter>

Filter to apply when updating existing points. Only points matching this filter will be updated. Points that don’t match will keep their current state. New points will be inserted regardless of the filter.

update_mode: Option<i32>

Mode of the upsert operation: insert_only, upsert (default), update_only

Implementations

Source

impl PointStructList

pub fn update_mode(&self) -> UpdateMode

Returns the enum value of update_mode, or the default if the field is unset or set to an invalid enum value.

pub fn set_update_mode(&mut self, value: UpdateMode)

Sets update_mode to the provided enum value.