pub struct BoolIndexParams {
pub on_disk: Option<bool>,
pub enable_hnsw: Option<bool>,
pub memory: Option<i32>,
}Fields
on_disk: Option<bool>👎Deprecated
Deprecated: use memory instead.
If true - store index on disk.
enable_hnsw: Option<bool>Enable HNSW graph building for this payload field. If true, builds additional HNSW links (Need payload_m > 0). Default: true.
memory: Option<i32>Memory placement of the index.
Overrides the deprecated on_disk flag if both are set.
Implementations
Sourceimpl BoolIndexParams
impl BoolIndexParams
Sourcepub fn on_disk(&self) -> bool
pub fn on_disk(&self) -> bool
Returns the value of on_disk, or the default value if on_disk is unset.
Sourcepub fn enable_hnsw(&self) -> bool
pub fn enable_hnsw(&self) -> bool
Returns the value of enable_hnsw, or the default value if enable_hnsw is unset.
Sourcepub fn memory(&self) -> Memory
pub fn memory(&self) -> Memory
Returns the enum value of memory, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_memory(&mut self, value: Memory)
pub fn set_memory(&mut self, value: Memory)
Sets memory to the provided enum value.