pub struct CollectionParamsDiff {
pub replication_factor: Option<u32>,
pub write_consistency_factor: Option<u32>,
pub on_disk_payload: Option<bool>,
pub read_fan_out_factor: Option<u32>,
pub read_fan_out_delay_ms: Option<u64>,
}Fields
replication_factor: Option<u32>Number of replicas of each shard that network tries to maintain
write_consistency_factor: Option<u32>How many replicas should apply the operation for us to consider it successful
on_disk_payload: Option<bool>If true - point’s payload will not be stored in memory
read_fan_out_factor: Option<u32>Fan-out every read request to these many additional remote nodes (and return first available response)
read_fan_out_delay_ms: Option<u64>Define number of milliseconds to wait before attempting to read from another replica.
Implementations
Sourceimpl CollectionParamsDiff
impl CollectionParamsDiff
Sourcepub fn replication_factor(&self) -> u32
pub fn replication_factor(&self) -> u32
Returns the value of replication_factor, or the default value if replication_factor is unset.
Sourcepub fn write_consistency_factor(&self) -> u32
pub fn write_consistency_factor(&self) -> u32
Returns the value of write_consistency_factor, or the default value if write_consistency_factor is unset.
Sourcepub fn on_disk_payload(&self) -> bool
pub fn on_disk_payload(&self) -> bool
Returns the value of on_disk_payload, or the default value if on_disk_payload is unset.
Sourcepub fn read_fan_out_factor(&self) -> u32
pub fn read_fan_out_factor(&self) -> u32
Returns the value of read_fan_out_factor, or the default value if read_fan_out_factor is unset.
Sourcepub fn read_fan_out_delay_ms(&self) -> u64
pub fn read_fan_out_delay_ms(&self) -> u64
Returns the value of read_fan_out_delay_ms, or the default value if read_fan_out_delay_ms is unset.