DenseVectorCreationConfig

Struct DenseVectorCreationConfig 

pub struct DenseVectorCreationConfig {
    pub size: u64,
    pub distance: i32,
    pub multivector_config: Option<MultiVectorConfig>,
    pub datatype: Option<i32>,
}
Dense vector creation parameters. Only includes immutable properties that define the vector space. Storage type, index, and quantization are configured separately.

Fields

size: u64

Size/dimensionality of the vectors

distance: i32

Distance function used for comparing vectors

multivector_config: Option<MultiVectorConfig>

Configuration for multi-vector search (e.g., ColBERT)

datatype: Option<i32>

Data type of the vectors (Float32, Float16, Uint8)

Implementations

Source

impl DenseVectorCreationConfig

pub fn distance(&self) -> Distance

Returns the enum value of distance, or the default if the field is set to an invalid enum value.

pub fn set_distance(&mut self, value: Distance)

Sets distance to the provided enum value.

pub fn datatype(&self) -> Datatype

Returns the enum value of datatype, or the default if the field is unset or set to an invalid enum value.

pub fn set_datatype(&mut self, value: Datatype)

Sets datatype to the provided enum value.