pub struct FeedbackItemBuilder { /* private fields */ }Implementations
Sourceimpl FeedbackItemBuilder
impl FeedbackItemBuilder
Sourcepub fn new(example: impl Into<VectorInput>, score: f32) -> Self
pub fn new(example: impl Into<VectorInput>, score: f32) -> Self
Create a new builder with an example and its score.
Arguments
example- The id or vector from the original model.score- Score for this vector as determined by the feedback provider.
Examples
use qdrant_client::qdrant::{FeedbackItemBuilder, PointId, VectorInput};
let item = FeedbackItemBuilder::new(VectorInput::new_id(PointId::from(42)), 0.9);Sourcepub fn build(self) -> FeedbackItem
pub fn build(self) -> FeedbackItem
Builds the desired type. Can often be omitted.