pub struct FloatIndexParams {
pub on_disk: Option<bool>,
pub is_principal: Option<bool>,
pub enable_hnsw: Option<bool>,
pub memory: Option<i32>,
}Fields
on_disk: Option<bool>Deprecated: use memory instead.
If true - store index on disk.
is_principal: Option<bool>If true - use this key to organize storage of the collection data. This option assumes that this key will be used in majority of filtered requests.
enable_hnsw: Option<bool>Enable HNSW graph building for this payload field. If true, builds additional HNSW links (Need payload_m > 0). Default: true.
memory: Option<i32>Memory placement of the index.
Overrides the deprecated on_disk flag if both are set.
Implementations
Sourceimpl FloatIndexParams
impl FloatIndexParams
Sourcepub fn on_disk(&self) -> bool
pub fn on_disk(&self) -> bool
Returns the value of on_disk, or the default value if on_disk is unset.
Sourcepub fn is_principal(&self) -> bool
pub fn is_principal(&self) -> bool
Returns the value of is_principal, or the default value if is_principal is unset.
Sourcepub fn enable_hnsw(&self) -> bool
pub fn enable_hnsw(&self) -> bool
Returns the value of enable_hnsw, or the default value if enable_hnsw is unset.
Sourcepub fn memory(&self) -> Memory
pub fn memory(&self) -> Memory
Returns the enum value of memory, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_memory(&mut self, value: Memory)
pub fn set_memory(&mut self, value: Memory)
Sets memory to the provided enum value.