pub struct FormulaBuilder { /* private fields */ }Expand description
Builder for the Formula struct, which represents a scoring formula for points.
The Formula struct is used to define custom scoring expressions and default values.
Implementations
Sourceimpl FormulaBuilder
impl FormulaBuilder
Sourcepub fn new<E: Into<Expression>>(expression: E) -> Self
pub fn new<E: Into<Expression>>(expression: E) -> Self
Sets the expression for the formula.
pub fn expression<E: Into<Expression>>(self, value: E) -> Self