HnswConfigDiff

Struct HnswConfigDiff 

pub struct HnswConfigDiff {
    pub m: Option<u64>,
    pub ef_construct: Option<u64>,
    pub full_scan_threshold: Option<u64>,
    pub max_indexing_threads: Option<u64>,
    pub on_disk: Option<bool>,
    pub payload_m: Option<u64>,
    pub inline_storage: Option<bool>,
    pub memory: Option<i32>,
}

Fields

m: Option<u64>

Number of edges per node in the index graph. Larger the value - more accurate the search, more space required.

ef_construct: Option<u64>

Number of neighbours to consider during the index building. Larger the value - more accurate the search, more time required to build the index.

full_scan_threshold: Option<u64>

Minimal size threshold (in KiloBytes) below which full-scan is preferred over HNSW search. This measures the total size of vectors being queried against. When the maximum estimated amount of points that a condition satisfies is smaller than full_scan_threshold, the query planner will use full-scan search instead of HNSW index traversal for better performance. Note: 1Kb = 1 vector of size 256

max_indexing_threads: Option<u64>

Number of parallel threads used for background index building. If 0 - automatically select from 8 to 16. Best to keep between 8 and 16 to prevent likelihood of building broken/inefficient HNSW graphs. On small CPUs, less threads are used.

on_disk: Option<bool>
👎Deprecated

Deprecated: use memory instead. Store HNSW index on disk. If set to false, the index will be stored in RAM.

payload_m: Option<u64>

Number of additional payload-aware links per node in the index graph. If not set - regular M parameter will be used.

inline_storage: Option<bool>

Store copies of original and quantized vectors within the HNSW index file. Default: false. Enabling this option will trade the search speed for disk usage by reducing amount of random seeks during the search. Requires quantized vectors to be enabled. Multi-vectors are not supported.

memory: Option<i32>

Memory placement of the HNSW graph. Overrides the deprecated on_disk flag if both are set.

Implementations

Source

impl HnswConfigDiff

pub fn m(&self) -> u64

Returns the value of m, or the default value if m is unset.

pub fn ef_construct(&self) -> u64

Returns the value of ef_construct, or the default value if ef_construct is unset.

pub fn full_scan_threshold(&self) -> u64

Returns the value of full_scan_threshold, or the default value if full_scan_threshold is unset.

pub fn max_indexing_threads(&self) -> u64

Returns the value of max_indexing_threads, or the default value if max_indexing_threads is unset.

pub fn on_disk(&self) -> bool

Returns the value of on_disk, or the default value if on_disk is unset.

pub fn payload_m(&self) -> u64

Returns the value of payload_m, or the default value if payload_m is unset.

pub fn inline_storage(&self) -> bool

Returns the value of inline_storage, or the default value if inline_storage is unset.

pub fn memory(&self) -> Memory

Returns the enum value of memory, or the default if the field is unset or set to an invalid enum value.

pub fn set_memory(&mut self, value: Memory)

Sets memory to the provided enum value.