pub struct IntegerIndexParams {
pub lookup: Option<bool>,
pub range: Option<bool>,
pub is_principal: Option<bool>,
pub on_disk: Option<bool>,
pub enable_hnsw: Option<bool>,
}Fields
lookup: Option<bool>If true - support direct lookups. Default is true.
range: Option<bool>If true - support ranges filters. Default is true.
is_principal: Option<bool>If true - use this key to organize storage of the collection data. This option assumes that this key will be used in majority of filtered requests. Default is false.
on_disk: Option<bool>If true - store index on disk. Default is false.
enable_hnsw: Option<bool>Enable HNSW graph building for this payload field. If true, builds additional HNSW links (Need payload_m > 0). Default: true.
Implementations
Sourceimpl IntegerIndexParams
impl IntegerIndexParams
Sourcepub fn lookup(&self) -> bool
pub fn lookup(&self) -> bool
Returns the value of lookup, or the default value if lookup is unset.
Sourcepub fn range(&self) -> bool
pub fn range(&self) -> bool
Returns the value of range, or the default value if range is unset.
Sourcepub fn is_principal(&self) -> bool
pub fn is_principal(&self) -> bool
Returns the value of is_principal, or the default value if is_principal is unset.
Sourcepub fn on_disk(&self) -> bool
pub fn on_disk(&self) -> bool
Returns the value of on_disk, or the default value if on_disk is unset.
Sourcepub fn enable_hnsw(&self) -> bool
pub fn enable_hnsw(&self) -> bool
Returns the value of enable_hnsw, or the default value if enable_hnsw is unset.