pub struct ProductQuantization {
pub compression: i32,
pub always_ram: Option<bool>,
pub memory: Option<i32>,
}Fields
compression: i32Compression ratio
always_ram: Option<bool>👎Deprecated
Deprecated: use memory instead.
If true - quantized vectors always will be stored in RAM, ignoring the config of main storage
memory: Option<i32>Memory placement of quantized vectors.
Overrides the deprecated always_ram flag if both are set.
Implementations
Sourceimpl ProductQuantization
impl ProductQuantization
Sourcepub fn compression(&self) -> CompressionRatio
pub fn compression(&self) -> CompressionRatio
Returns the enum value of compression, or the default if the field is set to an invalid enum value.
Sourcepub fn set_compression(&mut self, value: CompressionRatio)
pub fn set_compression(&mut self, value: CompressionRatio)
Sets compression to the provided enum value.
Sourcepub fn always_ram(&self) -> bool
pub fn always_ram(&self) -> bool
Returns the value of always_ram, or the default value if always_ram is unset.
Sourcepub fn memory(&self) -> Memory
pub fn memory(&self) -> Memory
Returns the enum value of memory, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_memory(&mut self, value: Memory)
pub fn set_memory(&mut self, value: Memory)
Sets memory to the provided enum value.