Struct qdrant_client::qdrant::RecommendPointGroups
source · pub struct RecommendPointGroups {Show 15 fields
pub collection_name: String,
pub positive: Vec<PointId>,
pub negative: Vec<PointId>,
pub filter: Option<Filter>,
pub limit: u32,
pub with_payload: Option<WithPayloadSelector>,
pub params: Option<SearchParams>,
pub score_threshold: Option<f32>,
pub using: Option<String>,
pub with_vectors: Option<WithVectorsSelector>,
pub lookup_from: Option<LookupLocation>,
pub group_by: String,
pub group_size: u32,
pub read_consistency: Option<ReadConsistency>,
pub with_lookup: Option<WithLookup>,
}Fields
collection_name: StringName of the collection
positive: Vec<PointId>Look for vectors closest to those
negative: Vec<PointId>Try to avoid vectors like this
filter: Option<Filter>Filter conditions - return only those points that satisfy the specified conditions
limit: u32Max number of groups in result
with_payload: Option<WithPayloadSelector>Options for specifying which payload to include or not
params: Option<SearchParams>Search config
score_threshold: Option<f32>If provided - cut off results with worse scores
using: Option<String>Define which vector to use for recommendation, if not specified - default vector
with_vectors: Option<WithVectorsSelector>Options for specifying which vectors to include into response
lookup_from: Option<LookupLocation>Name of the collection to use for points lookup, if not specified - use current collection
group_by: StringPayload field to group by, must be a string or number field. If there are multiple values for the field, all of them will be used. One point can be in multiple groups.
group_size: u32Maximum amount of points to return per group
read_consistency: Option<ReadConsistency>Options for specifying read consistency guarantees
with_lookup: Option<WithLookup>Options for specifying how to use the group id to lookup points in another collection
Implementations