Struct qdrant_client::qdrant::RecommendPoints
source · pub struct RecommendPoints {Show 13 fields
pub collection_name: String,
pub positive: Vec<PointId>,
pub negative: Vec<PointId>,
pub filter: Option<Filter>,
pub limit: u64,
pub with_payload: Option<WithPayloadSelector>,
pub params: Option<SearchParams>,
pub score_threshold: Option<f32>,
pub offset: Option<u64>,
pub using: Option<String>,
pub with_vectors: Option<WithVectorsSelector>,
pub lookup_from: Option<LookupLocation>,
pub read_consistency: Option<ReadConsistency>,
}Fields
collection_name: Stringname of the collection
positive: Vec<PointId>Look for vectors closest to those
negative: Vec<PointId>Try to avoid vectors like this
filter: Option<Filter>Filter conditions - return only those points that satisfy the specified conditions
limit: u64Max number of result
with_payload: Option<WithPayloadSelector>Options for specifying which payload to include or not
params: Option<SearchParams>Search config
score_threshold: Option<f32>If provided - cut off results with worse scores
offset: Option<u64>Offset of the result
using: Option<String>Define which vector to use for recommendation, if not specified - default vector
with_vectors: Option<WithVectorsSelector>Options for specifying which vectors to include into response
lookup_from: Option<LookupLocation>Name of the collection to use for points lookup, if not specified - use current collection
read_consistency: Option<ReadConsistency>Options for specifying read consistency guarantees
Implementations
sourceimpl RecommendPoints
impl RecommendPoints