pub struct Rrf {
pub k: Option<u32>,
pub weights: Vec<f32>,
}Expand description
Parameterized reciprocal rank fusion
Fields
k: Option<u32>K parameter for reciprocal rank fusion
weights: Vec<f32>Weights for each prefetch source. Higher weight gives more influence on the final ranking. If not specified, all prefetches are weighted equally. The number of weights should match the number of prefetches.
Implementations