pub struct SliceCondition {
pub total: u32,
pub index: u32,
}Fields
total: u32Total number of disjoint deterministic slices the id space is split into, must be >= 1
index: u32Which slice to select, must be less than total