pub struct SparseIndexConfig {
pub full_scan_threshold: Option<u64>,
pub on_disk: Option<bool>,
pub datatype: Option<i32>,
pub memory: Option<i32>,
}Fields
full_scan_threshold: Option<u64>Prefer a full scan search upto (excluding) this number of vectors. Note: this is number of vectors, not KiloBytes.
on_disk: Option<bool>Deprecated: use memory instead.
Store inverted index on disk. If set to false, the index will be stored in RAM.
datatype: Option<i32>Datatype used to store weights in the index.
memory: Option<i32>Memory placement of the index.
Overrides the deprecated on_disk flag if both are set.
Implementations
Sourceimpl SparseIndexConfig
impl SparseIndexConfig
Sourcepub fn full_scan_threshold(&self) -> u64
pub fn full_scan_threshold(&self) -> u64
Returns the value of full_scan_threshold, or the default value if full_scan_threshold is unset.
Sourcepub fn on_disk(&self) -> bool
pub fn on_disk(&self) -> bool
Returns the value of on_disk, or the default value if on_disk is unset.
Sourcepub fn datatype(&self) -> Datatype
pub fn datatype(&self) -> Datatype
Returns the enum value of datatype, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_datatype(&mut self, value: Datatype)
pub fn set_datatype(&mut self, value: Datatype)
Sets datatype to the provided enum value.
Sourcepub fn memory(&self) -> Memory
pub fn memory(&self) -> Memory
Returns the enum value of memory, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_memory(&mut self, value: Memory)
pub fn set_memory(&mut self, value: Memory)
Sets memory to the provided enum value.