pub struct TurboQuantization {
pub always_ram: Option<bool>,
pub bits: Option<i32>,
}Fields
always_ram: Option<bool>bits: Option<i32>Implementations
Sourceimpl TurboQuantization
impl TurboQuantization
Sourcepub fn always_ram(&self) -> bool
pub fn always_ram(&self) -> bool
Returns the value of always_ram, or the default value if always_ram is unset.
Sourcepub fn bits(&self) -> TurboQuantBitSize
pub fn bits(&self) -> TurboQuantBitSize
Returns the enum value of bits, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_bits(&mut self, value: TurboQuantBitSize)
pub fn set_bits(&mut self, value: TurboQuantBitSize)
Sets bits to the provided enum value.