UpsertPoints

Struct UpsertPoints 

pub struct UpsertPoints {
    pub collection_name: String,
    pub wait: Option<bool>,
    pub points: Vec<PointStruct>,
    pub ordering: Option<WriteOrdering>,
    pub shard_key_selector: Option<ShardKeySelector>,
    pub update_filter: Option<Filter>,
    pub timeout: Option<u64>,
    pub update_mode: Option<i32>,
}

Fields

collection_name: String

name of the collection

wait: Option<bool>

Wait until the changes have been applied?

points: Vec<PointStruct>ordering: Option<WriteOrdering>

Write ordering guarantees

shard_key_selector: Option<ShardKeySelector>

Option for custom sharding to specify used shard keys

update_filter: Option<Filter>

Filter to apply when updating existing points. Only points matching this filter will be updated. Points that don’t match will keep their current state. New points will be inserted regardless of the filter.

timeout: Option<u64>

Timeout for the request in seconds

update_mode: Option<i32>

Mode of the upsert operation: insert_only, upsert (default), update_only

Implementations

Source

impl UpsertPoints

pub fn wait(&self) -> bool

Returns the value of wait, or the default value if wait is unset.

pub fn timeout(&self) -> u64

Returns the value of timeout, or the default value if timeout is unset.

pub fn update_mode(&self) -> UpdateMode

Returns the enum value of update_mode, or the default if the field is unset or set to an invalid enum value.

pub fn set_update_mode(&mut self, value: UpdateMode)

Sets update_mode to the provided enum value.