pub struct UpsertPointsBuilder { /* private fields */ }Implementations
Sourceimpl UpsertPointsBuilder
impl UpsertPointsBuilder
Sourcepub fn collection_name(self, value: String) -> Self
pub fn collection_name(self, value: String) -> Self
name of the collection
pub fn points(self, value: Vec<PointStruct>) -> Self
Sourcepub fn ordering<VALUE: Into<WriteOrdering>>(self, value: VALUE) -> Self
pub fn ordering<VALUE: Into<WriteOrdering>>(self, value: VALUE) -> Self
Write ordering guarantees
Sourcepub fn shard_key_selector<VALUE: Into<ShardKeySelector>>(
self,
value: VALUE,
) -> Self
pub fn shard_key_selector<VALUE: Into<ShardKeySelector>>( self, value: VALUE, ) -> Self
Option for custom sharding to specify used shard keys
Sourcepub fn update_filter<VALUE: Into<Filter>>(self, value: VALUE) -> Self
pub fn update_filter<VALUE: Into<Filter>>(self, value: VALUE) -> Self
Optional filter to apply to the upsert operation. If set, only points matching the filter will be updated, others will be inserted.
Sourcepub fn update_mode(self, value: UpdateMode) -> Self
pub fn update_mode(self, value: UpdateMode) -> Self
Mode of the upsert operation: insert_only, upsert (default), update_only
Sourceimpl UpsertPointsBuilder
impl UpsertPointsBuilder
Sourcepub fn build(self) -> UpsertPoints
pub fn build(self) -> UpsertPoints
Builds the desired type. Can often be omitted.