Struct qdrant_client::qdrant::points_client::PointsClient
source · pub struct PointsClient<T> { /* private fields */ }Implementations
sourceimpl PointsClient<Channel>
impl PointsClient<Channel>
sourceimpl<T> PointsClient<T>where
T: GrpcService<BoxBody>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> PointsClient<T>where T: GrpcService<BoxBody>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>( inner: T, interceptor: F ) -> PointsClient<InterceptedService<T, F>>where F: Interceptor, T::ResponseBody: Default, T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>, <T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,
sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
sourcepub async fn upsert(
&mut self,
request: impl IntoRequest<UpsertPoints>
) -> Result<Response<PointsOperationResponse>, Status>
pub async fn upsert( &mut self, request: impl IntoRequest<UpsertPoints> ) -> Result<Response<PointsOperationResponse>, Status>
Perform insert + updates on points. If a point with a given ID already exists - it will be overwritten.
sourcepub async fn delete(
&mut self,
request: impl IntoRequest<DeletePoints>
) -> Result<Response<PointsOperationResponse>, Status>
pub async fn delete( &mut self, request: impl IntoRequest<DeletePoints> ) -> Result<Response<PointsOperationResponse>, Status>
Delete points
sourcepub async fn get(
&mut self,
request: impl IntoRequest<GetPoints>
) -> Result<Response<GetResponse>, Status>
pub async fn get( &mut self, request: impl IntoRequest<GetPoints> ) -> Result<Response<GetResponse>, Status>
Retrieve points
sourcepub async fn update_vectors(
&mut self,
request: impl IntoRequest<UpdatePointVectors>
) -> Result<Response<PointsOperationResponse>, Status>
pub async fn update_vectors( &mut self, request: impl IntoRequest<UpdatePointVectors> ) -> Result<Response<PointsOperationResponse>, Status>
Update named vectors for point
sourcepub async fn delete_vectors(
&mut self,
request: impl IntoRequest<DeletePointVectors>
) -> Result<Response<PointsOperationResponse>, Status>
pub async fn delete_vectors( &mut self, request: impl IntoRequest<DeletePointVectors> ) -> Result<Response<PointsOperationResponse>, Status>
Delete named vectors for points
sourcepub async fn set_payload(
&mut self,
request: impl IntoRequest<SetPayloadPoints>
) -> Result<Response<PointsOperationResponse>, Status>
pub async fn set_payload( &mut self, request: impl IntoRequest<SetPayloadPoints> ) -> Result<Response<PointsOperationResponse>, Status>
Set payload for points
sourcepub async fn overwrite_payload(
&mut self,
request: impl IntoRequest<SetPayloadPoints>
) -> Result<Response<PointsOperationResponse>, Status>
pub async fn overwrite_payload( &mut self, request: impl IntoRequest<SetPayloadPoints> ) -> Result<Response<PointsOperationResponse>, Status>
Overwrite payload for points
sourcepub async fn delete_payload(
&mut self,
request: impl IntoRequest<DeletePayloadPoints>
) -> Result<Response<PointsOperationResponse>, Status>
pub async fn delete_payload( &mut self, request: impl IntoRequest<DeletePayloadPoints> ) -> Result<Response<PointsOperationResponse>, Status>
Delete specified key payload for points
sourcepub async fn clear_payload(
&mut self,
request: impl IntoRequest<ClearPayloadPoints>
) -> Result<Response<PointsOperationResponse>, Status>
pub async fn clear_payload( &mut self, request: impl IntoRequest<ClearPayloadPoints> ) -> Result<Response<PointsOperationResponse>, Status>
Remove all payload for specified points
sourcepub async fn create_field_index(
&mut self,
request: impl IntoRequest<CreateFieldIndexCollection>
) -> Result<Response<PointsOperationResponse>, Status>
pub async fn create_field_index( &mut self, request: impl IntoRequest<CreateFieldIndexCollection> ) -> Result<Response<PointsOperationResponse>, Status>
Create index for field in collection
sourcepub async fn delete_field_index(
&mut self,
request: impl IntoRequest<DeleteFieldIndexCollection>
) -> Result<Response<PointsOperationResponse>, Status>
pub async fn delete_field_index( &mut self, request: impl IntoRequest<DeleteFieldIndexCollection> ) -> Result<Response<PointsOperationResponse>, Status>
Delete field index for collection
sourcepub async fn search(
&mut self,
request: impl IntoRequest<SearchPoints>
) -> Result<Response<SearchResponse>, Status>
pub async fn search( &mut self, request: impl IntoRequest<SearchPoints> ) -> Result<Response<SearchResponse>, Status>
Retrieve closest points based on vector similarity and given filtering conditions
sourcepub async fn search_batch(
&mut self,
request: impl IntoRequest<SearchBatchPoints>
) -> Result<Response<SearchBatchResponse>, Status>
pub async fn search_batch( &mut self, request: impl IntoRequest<SearchBatchPoints> ) -> Result<Response<SearchBatchResponse>, Status>
Retrieve closest points based on vector similarity and given filtering conditions
sourcepub async fn search_groups(
&mut self,
request: impl IntoRequest<SearchPointGroups>
) -> Result<Response<SearchGroupsResponse>, Status>
pub async fn search_groups( &mut self, request: impl IntoRequest<SearchPointGroups> ) -> Result<Response<SearchGroupsResponse>, Status>
Retrieve closest points based on vector similarity and given filtering conditions, grouped by a given field
sourcepub async fn scroll(
&mut self,
request: impl IntoRequest<ScrollPoints>
) -> Result<Response<ScrollResponse>, Status>
pub async fn scroll( &mut self, request: impl IntoRequest<ScrollPoints> ) -> Result<Response<ScrollResponse>, Status>
Iterate over all or filtered points points
sourcepub async fn recommend(
&mut self,
request: impl IntoRequest<RecommendPoints>
) -> Result<Response<RecommendResponse>, Status>
pub async fn recommend( &mut self, request: impl IntoRequest<RecommendPoints> ) -> Result<Response<RecommendResponse>, Status>
Look for the points which are closer to stored positive examples and at the same time further to negative examples.
sourcepub async fn recommend_batch(
&mut self,
request: impl IntoRequest<RecommendBatchPoints>
) -> Result<Response<RecommendBatchResponse>, Status>
pub async fn recommend_batch( &mut self, request: impl IntoRequest<RecommendBatchPoints> ) -> Result<Response<RecommendBatchResponse>, Status>
Look for the points which are closer to stored positive examples and at the same time further to negative examples.
sourcepub async fn recommend_groups(
&mut self,
request: impl IntoRequest<RecommendPointGroups>
) -> Result<Response<RecommendGroupsResponse>, Status>
pub async fn recommend_groups( &mut self, request: impl IntoRequest<RecommendPointGroups> ) -> Result<Response<RecommendGroupsResponse>, Status>
Look for the points which are closer to stored positive examples and at the same time further to negative examples, grouped by a given field
sourcepub async fn count(
&mut self,
request: impl IntoRequest<CountPoints>
) -> Result<Response<CountResponse>, Status>
pub async fn count( &mut self, request: impl IntoRequest<CountPoints> ) -> Result<Response<CountResponse>, Status>
Count points in collection with given filtering conditions