pub struct SparseVectorCreationConfig {
pub modifier: Option<i32>,
pub datatype: Option<i32>,
}Expand description
Sparse vector creation parameters. Only includes immutable properties that define the vector space.
Fields
modifier: Option<i32>If set - apply modifier to the vector values (e.g., IDF)
datatype: Option<i32>Data type used to store weights in the index
Implementations
Sourceimpl SparseVectorCreationConfig
impl SparseVectorCreationConfig
Sourcepub fn modifier(&self) -> Modifier
pub fn modifier(&self) -> Modifier
Returns the enum value of modifier, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_modifier(&mut self, value: Modifier)
pub fn set_modifier(&mut self, value: Modifier)
Sets modifier to the provided enum value.
Sourcepub fn datatype(&self) -> Datatype
pub fn datatype(&self) -> Datatype
Returns the enum value of datatype, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_datatype(&mut self, value: Datatype)
pub fn set_datatype(&mut self, value: Datatype)
Sets datatype to the provided enum value.